==> common-1.3.0.90-sources.jar: cn/gtmap/gtc/workflow/domain/define/ProcessModel.java <==
package cn.gtmap.gtc.workflow.domain.define;


import java.util.List;

/**
 * @author zhouk
 * @Title: ProcessModel
 * @ProjectName procdef-core
 * @Description: TODO
 * @date 2018/6/2819:21
 */
public class ProcessModel extends Model {

    private String modelStatusKey;

    private String modelStatusName;

    private String modelCategoryKey;

    private String modelCategoryName;


    private Integer modelSort;


    private String departmentFilterRegion;


    public String getDepartmentFilterRegion() {
        return departmentFilterRegion;
    }

    public void setDepartmentFilterRegionStr(String departmentFilterRegion) {
        this.departmentFilterRegion = departmentFilterRegion;
    }
    public String getModelCategoryKey() {
        return modelCategoryKey;
    }

    public void setModelCategoryKey(String modelCategoryKey) {
        this.modelCategoryKey = modelCategoryKey;
    }

    public String getModelCategoryName() {
        return modelCategoryName;
    }

    public void setModelCategoryName(String modelCategoryName) {
        this.modelCategoryName = modelCategoryName;
    }

    public String getModelStatusKey() {
        return modelStatusKey;
    }

    public void setModelStatusKey(String modelStatusKey) {
        this.modelStatusKey = modelStatusKey;
    }

    public String getModelStatusName() {
        return modelStatusName;
    }

    public void setModelStatusName(String modelStatusName) {
        this.modelStatusName = modelStatusName;
    }

    public Integer getModelSort() {
        return modelSort;
    }

    public void setModelSort(Integer modelSort) {
        this.modelSort = modelSort;
    }
}

==> common-1.3.1.1-sources.jar: cn/gtmap/gtc/workflow/domain/define/ProcessModel.java <==
package cn.gtmap.gtc.workflow.domain.define;


import java.util.List;

/**
 * @author zhouk
 * @Title: ProcessModel
 * @ProjectName procdef-core
 * @Description: TODO
 * @date 2018/6/2819:21
 */
public class ProcessModel extends Model {

    private String modelStatusKey;

    private String modelStatusName;

    private String modelCategoryKey;

    private String modelCategoryName;


    private Integer modelSort;


    private String departmentFilterRegion;

    /**
     * 自动派件开启区县
     */
    private String dispatchRegion;


    public String getDepartmentFilterRegion() {
        return departmentFilterRegion;
    }

    public void setDepartmentFilterRegionStr(String departmentFilterRegion) {
        this.departmentFilterRegion = departmentFilterRegion;
    }

    public String getDispatchRegion() {
        return dispatchRegion;
    }

    public void setDispatchRegion(String dispatchRegion) {
        this.dispatchRegion = dispatchRegion;
    }

    public String getModelCategoryKey() {
        return modelCategoryKey;
    }

    public void setModelCategoryKey(String modelCategoryKey) {
        this.modelCategoryKey = modelCategoryKey;
    }

    public String getModelCategoryName() {
        return modelCategoryName;
    }

    public void setModelCategoryName(String modelCategoryName) {
        this.modelCategoryName = modelCategoryName;
    }

    public String getModelStatusKey() {
        return modelStatusKey;
    }

    public void setModelStatusKey(String modelStatusKey) {
        this.modelStatusKey = modelStatusKey;
    }

    public String getModelStatusName() {
        return modelStatusName;
    }

    public void setModelStatusName(String modelStatusName) {
        this.modelStatusName = modelStatusName;
    }

    public Integer getModelSort() {
        return modelSort;
    }

    public void setModelSort(Integer modelSort) {
        this.modelSort = modelSort;
    }
}
